@@ -3,28 +3,28 @@ use std::sync::atomic::{AtomicBool, Ordering};
 use std::sync::Arc;
 
 use actix::Message;
-use chrono::{DateTime, Utc};
-use serde::{Deserialize, Serialize};
+use chrono::DateTime;
+use near_primitives::time::Utc;
 
 use near_chain_configs::ProtocolConfigView;
 use near_network_primitives::types::{AccountOrPeerIdOrHash, KnownProducer, PeerInfo};
-use near_primitives_v01::errors::InvalidTxError;
-use near_primitives_v01::hash::CryptoHash;
-use near_primitives_v01::merkle::{MerklePath, PartialMerkleTree};
-use near_primitives_v01::sharding::ChunkHash;
-use near_primitives_v01::types::{
+use near_primitives::errors::InvalidTxError;
+use near_primitives::hash::CryptoHash;
+use near_primitives::merkle::{MerklePath, PartialMerkleTree};
+use near_primitives::sharding::ChunkHash;
+use near_primitives::types::{
     AccountId, BlockHeight, BlockReference, EpochReference, MaybeBlockId, ShardId,
     TransactionOrReceiptId,
 };
-use near_primitives_v01::utils::generate_random_string;
-use near_primitives_v01::views::validator_stake_view::ValidatorStakeView;
-use near_primitives_v01::views::{
+use near_primitives::utils::generate_random_string;
+use near_primitives::views::validator_stake_view::ValidatorStakeView;
+use near_primitives::views::{
     BlockView, ChunkView, EpochValidatorInfo, ExecutionOutcomeWithIdView,
     FinalExecutionOutcomeViewEnum, GasPriceView, LightClientBlockLiteView, LightClientBlockView,
     QueryRequest, QueryResponse, ReceiptView, StateChangesKindsView, StateChangesRequestView,
     StateChangesView,
 };
-pub use near_primitives_v01::views::{StatusResponse, StatusSyncInfo};
+pub use near_primitives::views::{StatusResponse, StatusSyncInfo};
 
 /// Combines errors coming from chain, tx pool and block producer.
 #[derive(Debug)]
@@ -283,51 +283,51 @@ pub enum QueryError {
     #[error("There are no fully synchronized blocks on the node yet")]
     NoSyncedBlocks,
     #[error("The node does not track the shard ID {requested_shard_id}")]
-    UnavailableShard { requested_shard_id: near_primitives_v01::types::ShardId },
+    UnavailableShard { requested_shard_id: near_primitives::types::ShardId },
     #[error("Account ID {requested_account_id} is invalid")]
     InvalidAccount {
-        requested_account_id: near_primitives_v01::types::AccountId,
-        block_height: near_primitives_v01::types::BlockHeight,
-        block_hash: near_primitives_v01::hash::CryptoHash,
+        requested_account_id: near_primitives::types::AccountId,
+        block_height: near_primitives::types::BlockHeight,
+        block_hash: near_primitives::hash::CryptoHash,
     },
     #[error(
         "Account {requested_account_id} does not exist while viewing at block #{block_height}"
     )]
     UnknownAccount {
-        requested_account_id: near_primitives_v01::types::AccountId,
-        block_height: near_primitives_v01::types::BlockHeight,
-        block_hash: near_primitives_v01::hash::CryptoHash,
+        requested_account_id: near_primitives::types::AccountId,
+        block_height: near_primitives::types::BlockHeight,
+        block_hash: near_primitives::hash::CryptoHash,
     },
     #[error(
         "Contract code for contract ID {contract_account_id} has never been observed on the node at block #{block_height}"
     )]
     NoContractCode {
-        contract_account_id: near_primitives_v01::types::AccountId,
-        block_height: near_primitives_v01::types::BlockHeight,
-        block_hash: near_primitives_v01::hash::CryptoHash,
+        contract_account_id: near_primitives::types::AccountId,
+        block_height: near_primitives::types::BlockHeight,
+        block_hash: near_primitives::hash::CryptoHash,
     },
     #[error("State of contract {contract_account_id} is too large to be viewed")]
     TooLargeContractState {
-        contract_account_id: near_primitives_v01::types::AccountId,
-        block_height: near_primitives_v01::types::BlockHeight,
-        block_hash: near_primitives_v01::hash::CryptoHash,
+        contract_account_id: near_primitives::types::AccountId,
+        block_height: near_primitives::types::BlockHeight,
+        block_hash: near_primitives::hash::CryptoHash,
     },
     #[error("Access key for public key {public_key} has never been observed on the node at block #{block_height}")]
     UnknownAccessKey {
-        public_key: near_crypto_v01::PublicKey,
-        block_height: near_primitives_v01::types::BlockHeight,
-        block_hash: near_primitives_v01::hash::CryptoHash,
+        public_key: near_crypto::PublicKey,
+        block_height: near_primitives::types::BlockHeight,
+        block_hash: near_primitives::hash::CryptoHash,
     },
     #[error("Function call returned an error: {vm_error}")]
     ContractExecutionError {
         vm_error: String,
-        block_height: near_primitives_v01::types::BlockHeight,
-        block_hash: near_primitives_v01::hash::CryptoHash,
+        block_height: near_primitives::types::BlockHeight,
+        block_hash: near_primitives::hash::CryptoHash,
     },
     #[error("The node reached its limits. Try again later. More details: {error_message}")]
     InternalError { error_message: String },
     #[error("Block either has never been observed on the node or has been garbage collected: {block_reference:?}")]
-    UnknownBlock { block_reference: near_primitives_v01::types::BlockReference },
+    UnknownBlock { block_reference: near_primitives::types::BlockReference },
     // NOTE: Currently, the underlying errors are too broad, and while we tried to handle
     // expected cases, we cannot statically guarantee that no other errors will be returned
     // in the future.
@@ -347,7 +347,7 @@ pub enum StatusError {
     #[error("No blocks for {elapsed:?}")]
     NoNewBlocks { elapsed: std::time::Duration },
     #[error("Epoch Out Of Bounds {epoch_id:?}")]
-    EpochOutOfBounds { epoch_id: near_primitives_v01::types::EpochId },
+    EpochOutOfBounds { epoch_id: near_primitives::types::EpochId },
     #[error("The node reached its limits. Try again later. More details: {error_message}")]
     InternalError { error_message: String },
     // NOTE: Currently, the underlying errors are too broad, and while we tried to handle
@@ -389,7 +389,7 @@ pub enum GetNextLightClientBlockError {
     #[error("Block either has never been observed on the node or has been garbage collected: {error_message}")]
     UnknownBlock { error_message: String },
     #[error("Epoch Out Of Bounds {epoch_id:?}")]
-    EpochOutOfBounds { epoch_id: near_primitives_v01::types::EpochId },
+    EpochOutOfBounds { epoch_id: near_primitives::types::EpochId },
     // NOTE: Currently, the underlying errors are too broad, and while we tried to handle
     // expected cases, we cannot statically guarantee that no other errors will be returned
     // in the future.
@@ -461,10 +461,10 @@ impl From<near_chain_primitives::Error> for GetGasPriceError {
     }
 }
 
-#[derive(Serialize, Deserialize, Debug)]
+#[derive(Debug)]
 pub struct NetworkInfoResponse {
-    pub active_peers: Vec<PeerInfo>,
-    pub num_active_peers: usize,
+    pub connected_peers: Vec<PeerInfo>,
+    pub num_connected_peers: usize,
     pub peer_max_count: u32,
     pub sent_bytes_per_sec: u64,
     pub received_bytes_per_sec: u64,
@@ -617,16 +617,16 @@ pub enum GetExecutionOutcomeError {
     #[error("Inconsistent state. Total number of shards is {number_or_shards} but the execution outcome is in shard {execution_outcome_shard_id}")]
     InconsistentState {
         number_or_shards: usize,
-        execution_outcome_shard_id: near_primitives_v01::types::ShardId,
+        execution_outcome_shard_id: near_primitives::types::ShardId,
     },
     #[error("{transaction_or_receipt_id} has not been confirmed")]
-    NotConfirmed { transaction_or_receipt_id: near_primitives_v01::hash::CryptoHash },
+    NotConfirmed { transaction_or_receipt_id: near_primitives::hash::CryptoHash },
     #[error("{transaction_or_receipt_id} does not exist")]
-    UnknownTransactionOrReceipt { transaction_or_receipt_id: near_primitives_v01::hash::CryptoHash },
+    UnknownTransactionOrReceipt { transaction_or_receipt_id: near_primitives::hash::CryptoHash },
     #[error("Node doesn't track the shard where {transaction_or_receipt_id} is executed")]
     UnavailableShard {
-        transaction_or_receipt_id: near_primitives_v01::hash::CryptoHash,
-        shard_id: near_primitives_v01::types::ShardId,
+        transaction_or_receipt_id: near_primitives::hash::CryptoHash,
+        shard_id: near_primitives::types::ShardId,
     },
     #[error("Internal error: {error_message}")]
     InternalError { error_message: String },
@@ -731,7 +731,7 @@ pub enum GetReceiptError {
     #[error("IO Error: {0}")]
     IOError(String),
     #[error("Receipt with id {0} has never been observed on this node")]
-    UnknownReceipt(near_primitives_v01::hash::CryptoHash),
+    UnknownReceipt(near_primitives::hash::CryptoHash),
     // NOTE: Currently, the underlying errors are too broad, and while we tried to handle
     // expected cases, we cannot statically guarantee that no other errors will be returned
     // in the future.
